@@ -1210,9 +1210,12 @@ class yank(commands.Command):
 		"path" : "get_rel_path",
 		"relative path" : "get_rel_path",
 		"absolute path" : "get_abs_path",
+		"url/raw@origin.git" : "get_url_raw_origin_git",
 		"url/origin.git" : "get_url_origin_git",
 		"url/origin.web" : "get_url_origin_web",
 		"url/commit" : "get_url_commit",
+		"url/file-on-current-branch" : "get_url_file_on_current_branch",
+		"url/file-perma-link" : "get_url_file_perma_link",
 	}
 
 	@classmethod
@@ -1330,21 +1333,45 @@ class yank(commands.Command):
 			raise ErrorInCommand(_("nothing has been searched for yet"))
 		return self.app.search_edit.get_last_input()
 
-	def get_rel_path(self, hash_id, type_id):
+	def get_rel_path(self, hash_id: str, type_id: str) -> 'str|None':
 		"""In details view: The path of the current file relative to the current working directory"""
 		return self.app.get_current_file_path()
 
-	def get_abs_path(self, hash_id, type_id):
+	def get_abs_path(self, hash_id: str, type_id: str) -> 'str|None':
 		"""In details view: The absolute path of the current file"""
 		fn = self.app.get_current_file_path()
 		if fn:
 			fn = os.path.abspath(fn)
 		return fn
 
-	def get_url_origin_git(self, hash_id: str, type_id: str) -> str:
+	def get_git_path(self, hash_id: str, type_id: str) -> 'str|None':
+		"""In details view: The path of the current file relative to the git root directory"""
+		fn = self.get_abs_path(hash_id, type_id)
+		if not fn:
+			return fn
+
+		root = model.get_git_root()
+		if not root:
+			raise ErrorInCommand(_("Failed to find git root directory"))
+
+		return os.path.relpath(fn, root)
+
+
+	def get_url_raw_origin_git(self, hash_id: str, type_id: str) -> str:
 		"""The output of `git remote get-url origin`"""
 		cmd = ['git', 'remote', 'get-url', 'origin']
-		return self.run_and_get_output(cmd).rstrip('\n')
+		try:
+			return self.run_and_get_output(cmd).rstrip('\n')
+		except model.CommandError:
+			raise ErrorInCommand(_("This repository has no remote called origin"))
+
+	def get_url_origin_git(self, hash_id: str, type_id: str) -> str:
+		"""The output of `git remote get-url origin` without username and password"""
+		url = self.get_url_raw_origin_git(hash_id, type_id)
+		m = re.match(r'(?P<start>[a-zA-Z]+://)(?P<stripped>[^@/]*@)(?P<end>.*)', url)
+		if not m:
+			return url
+		return m.group('start') + m.group('end')
 
 	def get_url_origin_web(self, hash_id: str, type_id: str) -> str:
 		"""The website of the remote repository called origin"""
@@ -1356,8 +1383,6 @@ class yank(commands.Command):
 	def get_url_commit(self, hash_id: str, type_id: str) -> str:
 		"""The website of the current commit on the remote repository called origin"""
 		url = self.get_url_origin_web(hash_id, type_id)
-		url = url.rstrip('.git')
-		url = url.rstrip('/')
 		if 'github.com' in url:
 			url += '/commit/%H'
 		elif 'bitbucket.org' in url:
@@ -1367,6 +1392,46 @@ class yank(commands.Command):
 			url += '/-/commit/%H'
 		return url
 
+	def get_url_file_perma_link(self, hash_id: str, type_id: str) -> str:
+		"""The website of the current file at the current commit"""
+		url = self.get_url_origin_web(hash_id, type_id)
+		if 'github.com' in url:
+			url += '/blob/%H/{fn}'
+		elif 'bitbucket.org' in url:
+			url += '/src/%H/{fn}'
+		else:
+			# gitlab
+			url += '/-/blob/%H/{fn}'
+
+		fn = self.get_git_path(hash_id, type_id)
+		if not fn:
+			raise ErrorInCommand(_("no file selected"))
+
+		url = url.format(fn=fn)
+		return url
+
+	def get_url_file_on_current_branch(self, hash_id: str, type_id: str) -> str:
+		"""The website of the current file at the current commit"""
+		url = self.get_url_origin_web(hash_id, type_id)
+		if 'github.com' in url:
+			url += '/blob/{branch}/{fn}'
+		elif 'bitbucket.org' in url:
+			url += '/src/{branch}/{fn}'
+		else:
+			# gitlab
+			url += '/-/blob/{branch}/{fn}'
+
+		fn = self.get_git_path(hash_id, type_id)
+		if not fn:
+			raise ErrorInCommand(_("no file selected"))
+
+		branch = model.get_current_branch()
+		if not branch:
+			raise ErrorInCommand(_("failed to get current branch"))
+
+		url = url.format(branch=branch, fn=fn)
+		return url
+
 
 	# ------- copy -------
 
@@ -1378,7 +1443,8 @@ class yank(commands.Command):
 		elif self.has_xclip():
 			self.copy_xclip(text, selection)
 		else:
-			raise ErrorInCommand(_("please install wl-copy, xsel or xclip in order to use this feature"))
+			self.app.show_error(text)
+			raise ErrorInCommand(_("please install wl-copy, xsel or xclip in order to copy this text"))
 
 		self.app.show_success(_("copied %r") % text)
 
@@ -1482,7 +1548,7 @@ class debug(commands.Command):
 
 
 if __name__ == '__main__':
-	import api_commands
-	import main
+	from . import api_commands
+	from . import main
 	cmdcont = api_commands.CommandContainer(main.App())
 	cmdcont.load_commands_from_list(locals().values())
