@@ -1418,6 +1418,10 @@ class DetailsModel(Model):
 		else:
 			t.append((_("Committer Date"), align_char + committer_date))
 
+		containing_tag = get_containing_tag(values['hash_id'], exclusive=False)
+		if containing_tag:
+			t.append((_("Released in"), containing_tag))
+
 		for ln in utils.format_table(t, fmt=['%s:']):
 			ln = utils.colored_str_to_markup(ln, define_color=self.app.define_color)
 			# wrap line in a tuple so that ALIGN_CHAR is not added again
@@ -1525,20 +1529,25 @@ def toggle_cmd_diff(log_args):
 
 # ---------- getters ----------
 
-def get_containing_tag(hash_id, exclusive):
+def get_containing_tag(hash_id: str, exclusive: bool) -> 'str|None':
+	'''
+	Return the first tag containing hash_id.
+	Prereleases are ignored if there is a real release
+	because --sort version:refname seems to sort prereleases after the real release.
+	'''
 	cmd = ["git", "tag", "--list", "--contains", hash_id, "--sort", "version:refname"]
 	out = Runner().run_and_get_output(cmd)
 	out = out.rstrip()
-	out = out.splitlines()
+	lines = out.splitlines()
 	if exclusive:
-		for tag in out:
+		for tag in lines:
 			if is_same_commit(tag, hash_id):
 				continue
 			return tag
 		return None
 
-	if out:
-		return out[0]
+	if lines:
+		return lines[0]
 	else:
 		return None
 
