@@ -1,13 +1,15 @@
 #!/usr/bin/env python3
 
 import math
+import collections.abc
 
-def generate_keys(alphabet, num_keys):
+def generate_keys(alphabet: str, num_keys: int) -> 'collections.abc.Iterable[str]':
 	if num_keys == 0:
 		return
 
 	a,b, len_keys = calc_key_length(alphabet, num_keys)
 
+	keys: 'collections.abc.Iterable[str]'
 	if len_keys > 1:
 		keys = alphabet
 		for i in range(len_keys - 2):
@@ -31,7 +33,7 @@ def generate_keys(alphabet, num_keys):
 			if i >= b:
 				return
 
-def calc_key_length(alphabet, num_keys):
+def calc_key_length(alphabet: str, num_keys: int) -> 'tuple[int, int, int]':
 	len_alphabet = len(alphabet)
 	len_key = math.ceil(math.log(num_keys, len_alphabet))
 	a = math.floor((len_alphabet**len_key - num_keys) / (len_alphabet - 1))
